@@ -10,10 +10,6 @@ import sys
 
 PYTHON_MAJOR_VER = sys.version_info[0]
 
-if PYTHON_MAJOR_VER == 2:
-    def bytes(byte_array):
-        return ''.join([chr(c) for c in byte_array])
-
 DEFAULT_CHARSET='UTF8'
 
 ISC_TIME_SECONDS_PRECISION = 10000
@@ -238,6 +234,7 @@ isc_dpb_specific_auth_data = 84
 isc_dpb_auth_plugin_list = 85
 isc_dpb_auth_plugin_name = 86
 isc_dpb_config = 87
+isc_dpb_nolinger = 88
 
 # Transaction Parameter Block parameter
 isc_tpb_version1 = 1
@@ -433,6 +430,17 @@ isc_arg_win32 = 17
 isc_arg_warning = 18
 isc_arg_sql_state = 19
 
+CNCT_user = 1
+CNCT_passwd = 2
+CNCT_host = 4
+CNCT_group = 5
+CNCT_user_verification = 6
+CNCT_specific_data = 7
+CNCT_plugin_name = 8
+CNCT_login = 9
+CNCT_plugin_list = 10
+CNCT_client_crypt = 11
+
 charset_map = {
     # DB CHAR SET NAME    :   PYTHON CODEC NAME (CANONICAL)
     # --------------------------------------------------------------------------
